==> variety_0.7.1.orig.tar.gz: variety-0.7.1/tests/test_lint.py <==
#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import unittest
import subprocess


class TestPylint(unittest.TestCase):
    def test_project_errors_only(self):
        '''run pylint in error only mode
        
        your code may well work even with pylint errors
        but have some unusual code'''
        return_code = subprocess.call(["pylint3", '-E', 'variety'])
        # not needed because nosetests displays pylint console output
        #self.assertEqual(return_code, 0)

    # un-comment the following for loads of diagnostics   
    #~ def test_project_full_report(self):
        #~ '''Only for the brave
#~ 
        #~ you will have to make judgement calls about your code standards
        #~ that differ from the norm'''
        #~ return_code = subprocess.call(["pylint", 'variety'])

if __name__ == '__main__':
    'you will get better results with nosetests'
    unittest.main()

==> variety_0.8.11.orig.tar.gz: variety-0.8.11/tests/test_lint.py <==
#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import subprocess
import unittest


class TestPylint(unittest.TestCase):
    def test_project_errors_only(self):
        """run pylint in error only mode
        
        your code may well work even with pylint errors
        but have some unusual code"""
        return_code = subprocess.call(["pylint3", "-E", "variety"])
        # not needed because nosetests displays pylint console output
        # self.assertEqual(return_code, 0)

    # un-comment the following for loads of diagnostics
    # ~ def test_project_full_report(self):
    # ~ '''Only for the brave


# ~
# ~ you will have to make judgement calls about your code standards
# ~ that differ from the norm'''
# ~ return_code = subprocess.call(["pylint", 'variety'])

if __name__ == "__main__":
    "you will get better results with nosetests"
    unittest.main()
